<?php

namespace General\Services\ChargeReport;

use General\Models\ChargeReport\BaiDuAdAccount;
use General\Models\Channel\ChannelUser;

class BaiDuAccountService
{
    private $report;

    public function __construct()
    {
        $this->report = new NotifyReport;
    }

    private function findChannelUser(string $phone)
    {
        return ChannelUser::where('phone', $phone)->first();
    }

    public function addBaiduAdAccount(array $data): BaiDuAdAccount
    {
        $phone = $data['phone'];
        $channel_user = $this->findChannelUser($phone);
        $model = BaiDuAdAccount::create(
            [
                'account_name' => $data['account_name'],
                'token' => $data['token'],
                'channel_user_id' => $channel_user->id,
                'is_enabled' => 1,
            ]
        );
        $this->report->baiDuAdAccountReport($model);
        return $model;
    }

    private function findBaiduAdAccount(int $id, string $phone): BaiDuAdAccount
    {
        $channel_user = $this->findChannelUser($phone);
        return BaiDuAdAccount::where('id', $id)->where('channel_user_id', $channel_user->id)->first();
    }

    public function delBaiduAdAccount(array $data)
    {
        $phone = $data['phone'];
        $model = $this->findBaiduAdAccount($data['id'], $phone);
        if ($model) {
            $model->is_enabled = 0;
            $model->save();
            $this->report->baiDuAdAccountReport($model);
        }
    }

    public function findBaiduAdAccounts(string $phone)
    {
        $channel_user = $this->findChannelUser($phone);
        return BaiDuAdAccount::where('is_enabled', 1)->where('channel_user_id', $channel_user->id)->get();
    }
}
